Changelog
---------

0.0.3 (2017-11-20)
~~~~~~~~~~~~~~~~~~~~~

- Includes the version, current user and role in javascript error reports.
  [href]

0.0.2 (2017-11-20)
~~~~~~~~~~~~~~~~~~~~~

- Moves yubikey/user registration toggles to configuration.
  [href]

0.0.1 (2017-11-16)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]